==> ksr-3.8.2.tgz: package/configuration/webpack/babelConf.js <==
let iffind = require('./ifFind')
let presets = [
  [
    require.resolve('@babel/preset-env'),
    {
      // tree shaking 必须禁止es6模块转换 ,毕竟依赖静态解析
      modules: false,
      loose: true,
      // debug: true,
      useBuiltIns: 'usage',
      corejs: { version: 3, proposals: true }
    }
  ]
]

let findreact = iffind('react')
let findvue = iffind('vue')

if(findreact){
  presets.push("@babel/preset-react")
}
if(findvue){
  presets.push("@vue/babel-preset-jsx")
}

module.exports = {
  cacheDirectory: true,
  presets: presets,
  plugins: [
    [
      require.resolve('@babel/plugin-proposal-decorators'),
      {
        legacy: true
      }
    ],
    [
      require.resolve('@babel/plugin-proposal-class-properties'),
      {
        loose: true
      }
    ],
    require.resolve('@babel/plugin-proposal-do-expressions'),
    require.resolve('@babel/plugin-proposal-export-default-from'),
    require.resolve('@babel/plugin-proposal-export-namespace-from'),
    require.resolve('@babel/plugin-proposal-function-bind'),
    require.resolve('@babel/plugin-proposal-function-sent'),
    require.resolve('@babel/plugin-proposal-json-strings'),
    require.resolve('@babel/plugin-proposal-logical-assignment-operators'),
    require.resolve('@babel/plugin-proposal-nullish-coalescing-operator'),
    require.resolve('@babel/plugin-proposal-numeric-separator'),
    require.resolve('@babel/plugin-proposal-object-rest-spread'),
    require.resolve('@babel/plugin-proposal-optional-chaining'),
    [
      require.resolve('@babel/plugin-proposal-pipeline-operator'),
      { proposal: 'minimal' }
    ],
    require.resolve('@babel/plugin-proposal-throw-expressions'),
    require.resolve('@babel/plugin-syntax-dynamic-import'),
    require.resolve('@babel/plugin-syntax-import-meta'),
    require.resolve('@babel/plugin-transform-destructuring'),
    require.resolve('@babel/plugin-transform-runtime'),
    require.resolve('@babel/plugin-transform-spread')
  ]
}

==> ksr-3.8.6.tgz: package/configuration/webpack/babelConf.js <==
let iffind = require('./ifFind')
let presets = [
  [
    require.resolve('@babel/preset-env'),
    {
      // tree shaking 必须禁止es6模块转换 ,毕竟依赖静态解析
      modules: false,
      loose: true,
      // debug: true,
      useBuiltIns: 'usage',
      corejs: { 
        version: 3, 
        proposals: true 
      }
    }
  ]
]

let findreact = iffind('react')
let findvue = iffind('vue')

if(findreact){
  presets.push("@babel/preset-react")
}
if(findvue){
  presets.push("@vue/babel-preset-jsx")
}

module.exports = {
  cacheDirectory: true,
  presets: presets,
  plugins: [
    [
      require.resolve('@babel/plugin-proposal-decorators'),
      {
        legacy: true
      }
    ],
    [
      require.resolve('@babel/plugin-proposal-class-properties'),
      {
        loose: true
      }
    ],
    require.resolve('@babel/plugin-proposal-do-expressions'),
    require.resolve('@babel/plugin-proposal-export-default-from'),
    require.resolve('@babel/plugin-proposal-export-namespace-from'),
    require.resolve('@babel/plugin-proposal-function-bind'),
    require.resolve('@babel/plugin-proposal-function-sent'),
    require.resolve('@babel/plugin-proposal-json-strings'),
    require.resolve('@babel/plugin-proposal-logical-assignment-operators'),
    require.resolve('@babel/plugin-proposal-nullish-coalescing-operator'),
    require.resolve('@babel/plugin-proposal-numeric-separator'),
    require.resolve('@babel/plugin-proposal-object-rest-spread'),
    require.resolve('@babel/plugin-proposal-optional-chaining'),
    [
      require.resolve('@babel/plugin-proposal-pipeline-operator'),
      { proposal: 'minimal' }
    ],
    require.resolve('@babel/plugin-proposal-throw-expressions'),
    require.resolve('@babel/plugin-syntax-dynamic-import'),
    require.resolve('@babel/plugin-syntax-import-meta'),
    require.resolve('@babel/plugin-transform-destructuring'),
    [require.resolve('@babel/plugin-transform-runtime'), {
      "corejs": 3,
      "helpers": true,
      "regenerator": true,
      "absoluteRuntime": false,
      "useESModules": false
    }],
    require.resolve('@babel/plugin-transform-spread'),
    require.resolve('@babel/plugin-transform-classes')
  ]
}
